@@ -12,7 +12,7 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::Array;
 
-our $VERSION = '2.020'; # VERSION
+our $VERSION = '2.023'; # VERSION
 
 use base 'PDF::API2::Basic::PDF::Objind';
 
@@ -22,20 +22,6 @@ use strict;
 
 PDF::API2::Basic::PDF::Array - Corresponds to a PDF array. Inherits from L<PDF::Objind>
 
-=head1 INSTANCE VARIABLES
-
-This object is not an array but an associative array containing the array of
-elements. Thus, there are special instance variables for an array object, beginning
-with a space
-
-=over
-
-=item var
-
-Contains the actual array of elements
-
-=back
-
 =head1 METHODS
 
 =head2 PDF::Array->new($parent, @vals)
@@ -89,12 +75,19 @@ sub removeobj {
 Returns a list of all the elements in the array. Notice that this is
 not the array itself but the elements in the array.
 
+Also available as C<elements>.
+
 =cut
 
 sub elementsof {
     return wantarray ? @{$_[0]->{' val'}} : scalar @{$_[0]->{' val'}};
 }
 
+sub elements {
+    my $self = shift();
+    return @{$self->{' val'}};
+}
+
 =head2 $a->add_elements
 
 Appends the given elements to the array. An element is only added if it
